@@ -1,11 +1,16 @@
 from django.contrib.contenttypes.models import ContentType
+
 from django_comments.forms import CommentSecurityForm
-from django_comments_xtd import get_model as get_comment_model
-from django_comments_xtd.conf import settings
-from django_comments_xtd.utils import get_current_site_id
 from rest_framework.response import Response
 from rest_framework.reverse import reverse
 
+from django_comments_xtd import get_model as get_comment_model
+from django_comments_xtd.conf import settings
+from django_comments_xtd.utils import (
+    get_current_site_id, get_app_model_options, get_html_id_suffix
+)
+
+
 XtdComment = get_comment_model()
 
 
@@ -25,7 +30,7 @@ def commentbox_props(obj, user, request=None):
             allow_feedback: false,
             show_feedback: false,
             can_moderate: <bool>,  // Whether current_user can moderate.
-            poll_interval: 2000, // Check for new comments every 2 seconds.
+            polling_interval: 2000, // Check for new comments every 2 seconds.
             feedback_url: <api-url-to-send-like/dislike-feedback>,
             delete_url: <api-url-for-moderators-to-remove-comment>,
             login_url: settings.LOGIN_URL,
@@ -33,7 +38,8 @@ def commentbox_props(obj, user, request=None):
             flag_url: <api-url-to-suggest-comment-removal>,
             list_url: <api-url-to-list-comments>,
             count_url: <api-url-to-count-comments>,
-            send_url: <api-irl-to-send-a-comment>,
+            send_url: <api-url-to-send-a-comment>,
+            preview_url: <api-url-to-preview-users-avatar>,
             form: {
                 content_type: <value>,
                 object_pk: <value>,
@@ -42,7 +48,8 @@ def commentbox_props(obj, user, request=None):
             },
             login_url: <only_when_user_is_not_authenticated>,
             like_url: <only_when_user_is_not_authenticated>,
-            dislike_url: <only_when_user_is_not_authenticated>
+            dislike_url: <only_when_user_is_not_authenticated>,
+            html_id_suffix: <html_element_id_suffix>
         }
     """
 
@@ -57,6 +64,8 @@ def commentbox_props(obj, user, request=None):
                                          site__pk=get_current_site_id(request),
                                          is_public=True)
     ctype_slug = "%s-%s" % (ctype.app_label, ctype.model)
+    ctype_key = "%s.%s" % (ctype.app_label, ctype.model)
+    options = get_app_model_options(content_type=ctype_key)
     d = {
         "comment_count": queryset.count(),
         "allow_comments": True,
@@ -64,11 +73,12 @@ def commentbox_props(obj, user, request=None):
         "request_name": False,
         "request_email_address": False,
         "is_authenticated": False,
+        "who_can_post": options['who_can_post'],
         "allow_flagging": False,
         "allow_feedback": False,
         "show_feedback": False,
         "can_moderate": False,
-        "poll_interval": 2000,
+        "polling_interval": 2000,
         "feedback_url": _reverse("comments-xtd-api-feedback"),
         "delete_url": _reverse("comments-delete", args=(0,)),
         "reply_url": _reverse("comments-xtd-reply", kwargs={'cid': 0}),
@@ -80,12 +90,14 @@ def commentbox_props(obj, user, request=None):
                               kwargs={'content_type': ctype_slug,
                                       'object_pk': obj.id}),
         "send_url": _reverse("comments-xtd-api-create"),
+        "preview_url": _reverse("comments-xtd-api-preview"),
         "form": {
             "content_type": form['content_type'].value(),
             "object_pk": form['object_pk'].value(),
             "timestamp": form['timestamp'].value(),
             "security_hash": form['security_hash'].value()
-        }
+        },
+        "html_id_suffix": get_html_id_suffix(obj)
     }
     try:
         user_is_authenticated = user.is_authenticated()
