@@ -29,7 +29,7 @@ class WriteCommentSerializer(serializers.Serializer):
     object_pk = serializers.CharField()
     timestamp = serializers.CharField(required=False)
     security_hash = serializers.CharField(required=False)
-    honeypot = serializers.CharField(required=False)
+    honeypot = serializers.CharField(required=False, allow_blank=True)
     name = serializers.CharField(allow_blank=True)
     email = serializers.EmailField(allow_blank=True)
     url = serializers.URLField(required=False)
@@ -149,7 +149,7 @@ class WriteCommentSerializer(serializers.Serializer):
             not settings.COMMENTS_XTD_CONFIRM_EMAIL or
             self.request.user.is_authenticated
         ):
-            if not views._comment_exists(resp['comment']):
+            if views._get_comment_if_exists(resp['comment']) is None:
                 new_comment = views._create_comment(resp['comment'])
                 resp['comment'].xtd_comment = new_comment
                 confirmation_received.send(sender=TmpXtdComment,
