@@ -1,6 +1,6 @@
 from django import forms
 from django.apps import apps
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from django_comments.forms import CommentForm
 
